@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Lean Prolog 4.5.7 and later versions
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -249,6 +249,12 @@ to_engine(Interactor, Pattern, Goal) :-
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(assert(_)).
@@ -296,9 +302,9 @@ to_engine(Interactor, Pattern, Goal) :-
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, lean).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, lprolog(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, '@>='((4, 5, 7))).
+'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(4, 5, 7))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, source).
@@ -503,33 +509,6 @@ to_engine(Interactor, Pattern, Goal) :-
 	getenv(Variable, Value).
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	(	getenv('LOGTALK_STARTUP_DIRECTORY', Directory) ->
-		true
-	;	working_directory(Directory, Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	getenv('LOGTALKUSER', Directory).
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	getenv('LOGTALKHOME', Directory).
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
@@ -603,14 +582,19 @@ to_engine(Interactor, Pattern, Goal) :-
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
 	'$lgt_read_term_options'(Options),
-	read_term(Stream, yes, Term, Variables, LineBegin0, LineEnd),
-	LineBegin is LineBegin0 + 1.
+	read_term(Stream, yes, Term, Variables0, LineBegin0, LineEnd),
+	LineBegin is LineBegin0 + 1,
+	'$lgt_lean_fix_variables_list'(Variables0, Variables).
 
 
 % hack for the only two cases of list of options used by the compiler
 '$lgt_read_term_options'([]).
 '$lgt_read_term_options'([singletons([])]).
 
+'$lgt_lean_fix_variables_list'([], []).
+'$lgt_lean_fix_variables_list'([Name-Variable| Variables0], [Name=Variable| Variables]) :-
+	'$lgt_lean_fix_variables_list'(Variables0, Variables).
+
 
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
