@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Ciao Prolog 1.14.0
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -173,6 +173,12 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(_) :-
@@ -221,11 +227,11 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, ciao).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version, ciao(Version, Patch)),
 	Major is truncate(float_integer_part(Version)),
 	Minor is truncate(float_fractional_part(Version)*100).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((1,10,5))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=(v(1,10,5))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
@@ -399,35 +405,6 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 	atom_codes(Value, String).
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	(	getenvstr('LOGTALK_STARTUP_DIRECTORY', String) ->
-		atom_codes(Directory, String)
-	;	working_directory(Directory, Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	getenvstr('LOGTALKUSER', String),
-	atom_codes(Directory, String).
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	getenvstr('LOGTALKHOME', String),
-	atom_codes(Directory, String).
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
