@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Jekejeke Prolog 1.0.4 and later versions
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -206,6 +206,12 @@ format(Format, Arguments) :-
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(_) :-
@@ -252,9 +258,9 @@ format(Format, Arguments) :-
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, jekejeke).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, jekejeke(Major, Minor, Patch)).
-'$lgt_prolog_feature'(prolog_compatible_version, '@>='((1, 0, 4))).
+'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(1, 0, 4))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, source).
@@ -455,33 +461,6 @@ format(Format, Arguments) :-
 	getenv(Variable, Value).
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	(	getenv('LOGTALK_STARTUP_DIRECTORY', Directory) ->
-		true
-	;	'$lgt_current_directory'(Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	getenv('LOGTALKUSER', Directory).
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	getenv('LOGTALKHOME', Directory).
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
