@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for tuProlog 2.9.0 and later versions
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -190,6 +190,12 @@ numbervars(Term, From, Next) :-
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(_) :-
@@ -236,9 +242,9 @@ numbervars(Term, From, Next) :-
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, tu).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Path)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Path)) :-
 	?????
-'$lgt_prolog_feature'(prolog_compatible_version, '@>='((2, 9, 0))).
+'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(2, 9, 0))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
@@ -422,34 +428,6 @@ numbervars(Term, From, Next) :-
 	class('java.lang.System') <- getenv(Variable) returns Value.
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	class('java.lang.System') <- getenv('LOGTALK_STARTUP_DIRECTORY') returns Directory,
-	(	nonvar(Directory) ->
-		true
-	;	'$lgt_current_directory'(Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	class('java.lang.System') <- getenv('LOGTALKUSER') returns Directory.
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	class('java.lang.System') <- getenv('LOGTALKHOME') returns Directory.
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
