@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for XSB 3.8.0 or later versions
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -161,6 +161,12 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(assert(_)).
@@ -209,9 +215,9 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, xsb).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, xsb(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((3,8,0))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=(v(3,8,0))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
@@ -410,33 +416,6 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 	expand_atom(Variable, Value).
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	(	expand_atom('$LOGTALK_STARTUP_DIRECTORY', Directory) ->
-		true
-	;	path_sysop(cwd, Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	expand_atom('$LOGTALKUSER', Directory).
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	expand_atom('$LOGTALKHOME', Directory).
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
