@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on June 18, 2018
+%  Last updated on July 23, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -219,6 +219,12 @@
 	fail.
 
 
+% '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
+	fail.
+
+
 % '$lgt_prolog_database_predicate'(@callable)
 
 '$lgt_prolog_database_predicate'(assert(_)).
@@ -274,9 +280,9 @@
 % back-end Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, yap).
-'$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
+'$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, yap(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((6,3,4))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=(v(6,3,4))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, full).
@@ -501,33 +507,6 @@
 	environ(Variable, Value).
 
 
-% '$lgt_startup_directory'(-atom)
-%
-% returns the Logtalk startup directory
-
-'$lgt_startup_directory'(Directory) :-
-	(	environ('LOGTALK_STARTUP_DIRECTORY', Directory) ->
-		true
-	;	working_directory(Directory, Directory)
-	).
-
-
-% '$lgt_user_directory'(-atom)
-%
-% returns the Logtalk user directory; fails if unknown
-
-'$lgt_user_directory'(Directory) :-
-	environ('LOGTALKUSER', Directory).
-
-
-% '$lgt_home_directory'(-atom)
-%
-% returns the Logtalk home directory; fails if unknown
-
-'$lgt_home_directory'(Directory) :-
-	environ('LOGTALKHOME', Directory).
-
-
 % '$lgt_decompose_file_name'(+atom, ?atom, ?atom, ?atom)
 %
 % decomposes a file path in its components; the directory must always end
@@ -690,7 +669,7 @@
 	(	absolute_file_name(File, Path, [file_type(prolog), access(read), file_errors(fail)]),
 		file_property(Path, type(regular))
 	;	% we may be compiling Prolog module files as Logtalk objects
-		absolute_file_name(File, Path, [extensions(['.lgt']), access(read), file_errors(fail)])
+		absolute_file_name(File, Path, [extensions(['.lgt','.logtalk']), access(read), file_errors(fail)])
 	),
 	open(Path, read, In),
 	(	peek_char(In, #) ->		% deal with #! script; if not present
