@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths
-%  Last updated on June 10, 2018
+%  Last updated on July 4, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -101,6 +101,7 @@ logtalk_library_path(assignvars, examples('assignvars/')).
 logtalk_library_path(assumptions, examples('assumptions/')).
 logtalk_library_path(attvars, examples('attvars/')).
 logtalk_library_path(barriers, threads('barriers/')).
+logtalk_library_path(bench, examples('bench/')).
 logtalk_library_path(benchmarks, examples('benchmarks/')).
 logtalk_library_path(birds, examples('birds/')).
 logtalk_library_path(birthdays, threads('birthdays/')).
@@ -182,6 +183,7 @@ logtalk_library_path(multifile, examples('multifile/')).
 logtalk_library_path(my_types, examples('my_types/')).
 logtalk_library_path(named_databases, examples('named_databases/')).
 logtalk_library_path(nondet, threads('nondet/')).
+logtalk_library_path(now_you_see_me, examples('now_you_see_me/')).
 logtalk_library_path(operators, examples('operators/')).
 logtalk_library_path(optionals, examples('optionals/')).
 logtalk_library_path(patches, examples('patches/')).
